{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": "${\n  var listing = [\n    {\n      \"entry\": inputs.fastq_file_r1,\n      \"entryname\": \"sample_S1_L001_R1_001.fastq.gz\",\n      \"writable\": true\n    },\n    {\n      \"entry\": inputs.fastq_file_r2,\n      \"entryname\": \"sample_S1_L001_R2_001.fastq.gz\",\n      \"writable\": true\n    }\n  ];\n  if (inputs.fastq_file_i1){\n    listing.push(\n      {\n        \"entry\": inputs.fastq_file_i1,\n        \"entryname\": \"sample_S1_L001_I1_001.fastq.gz\",\n        \"writable\": true\n      }\n    );\n  };\n  return listing;\n}\n"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "cumulusprod/cellranger:4.0.0"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "Fastq file 3 (if provided, will be staged into workdir as sample_S1_L001_I1_001.fastq.gz)\n",
                    "id": "#cellranger-count.cwl/fastq_file_i1"
                },
                {
                    "type": "File",
                    "doc": "Fastq file 1 (will be staged into workdir as sample_S1_L001_R1_001.fastq.gz)\n",
                    "id": "#cellranger-count.cwl/fastq_file_r1"
                },
                {
                    "type": "File",
                    "doc": "Fastq file 2 (will be staged into workdir as sample_S1_L001_R2_001.fastq.gz)\n",
                    "id": "#cellranger-count.cwl/fastq_file_r2"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--transcriptome"
                    },
                    "doc": "Path of folder containing 10x-compatible transcriptome reference.\nShould be generated by \"cellranger mkref\" command\n",
                    "id": "#cellranger-count.cwl/indices_folder"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "--localmem"
                    },
                    "doc": "Set max GB the pipeline may request at one time\nDefault: all available\n",
                    "id": "#cellranger-count.cwl/memory_limit"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--localcores"
                    },
                    "doc": "Set max cores the pipeline may request at one time.\nDefault: all available\n",
                    "id": "#cellranger-count.cwl/threads"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "--localvmem"
                    },
                    "doc": "Set max virtual address space in GB for the pipeline\nDefault: all available\n",
                    "id": "#cellranger-count.cwl/virt_memory_limit"
                }
            ],
            "baseCommand": [
                "cellranger",
                "count",
                "--disable-ui",
                "--fastqs",
                ".",
                "--id",
                "sample"
            ],
            "stdout": "cellranger_count_stdout.log",
            "stderr": "cellranger_count_stderr.log",
            "label": "Cellranger count - generates single cell feature counts for a single library",
            "doc": "Generates single cell feature counts for a single library.\n\nInput parameters for Feature Barcode, Targeted Gene Expression and CRISPR-specific\nanalyses are not implemented, therefore the correspondent outputs are also excluded.\n\nParameters set by default:\n--disable-ui - no need in any UI when running in Docker container\n--id - can be hardcoded as we rename input files anyway\n--fastqs - points to the current directory, because input FASTQ files are staged there\n\nWhy do we need to rename input files?\nRefer to the \"My FASTQs are not named like any of the above examples\" section of\nhttps://support.10xgenomics.com/single-cell-gene-expression/software/pipelines/latest/using/fastq-input\n",
            "id": "#cellranger-count.cwl",
            "http://schema.org/name": "Cellranger count - generates single cell feature counts for a single library",
            "http://schema.org/alternateName": "Counts gene expression and feature barcoding reads from a single sample and GEM well",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/cellranger-count.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Count gene expression and feature barcoding reads from a single sample and GEM well\n\nUSAGE:\n    cellranger count [FLAGS] [OPTIONS] --id <ID> --transcriptome <PATH>\n\nFLAGS:\n        --no-target-umi-filter    Turn off the target UMI filtering subpipeline\n        --nosecondary             Disable secondary analysis, e.g. clustering. Optional\n        --no-libraries            Proceed with processing using a --feature-ref but no Feature Barcode libraries specified with the 'libraries' flag\n        --dry                     Do not execute the pipeline. Generate a pipeline invocation (.mro) file and stop\n        --disable-ui              Do not serve the UI\n        --noexit                  Keep web UI running after pipestance completes or fails\n        --nopreflight             Skip preflight checks\n    -h, --help                    Prints help information\n\nOPTIONS:\n        --id <ID>                 A unique run id and output folder name [a-zA-Z0-9_-]+\n        --description <TEXT>      Sample description to embed in output files\n        --transcriptome <PATH>    Path of folder containing 10x-compatible transcriptome reference\n    -f, --fastqs <PATH>...        Path to input FASTQ data\n    -p, --project <TEXT>          Name of the project folder within a mkfastq or bcl2fastq-generated folder to pick FASTQs from\n    -s, --sample <PREFIX>...      Prefix of the filenames of FASTQs to select\n        --lanes <NUMS>...         Only use FASTQs from selected lanes\n        --libraries <CSV>         CSV file declaring input library data sources\n        --feature-ref <CSV>       Feature reference CSV file, declaring Feature Barcode constructs and associated barcodes\n        --target-panel <CSV>      The target panel CSV file declaring the target panel used, if any\n        --expect-cells <NUM>      Expected number of recovered cells\n        --force-cells <NUM>       Force pipeline to use this number of cells, bypassing cell detection\n        --r1-length <NUM>         Hard trim the input Read 1 to this length before analysis\n        --r2-length <NUM>         Hard trim the input Read 2 to this length before analysis\n        --chemistry <CHEM>        Assay configuration. NOTE: by default the assay configuration is detected automatically, which is the recommened mode. You usually will not need\n                                  to specify a chemistry. Options are: 'auto' for autodetection, 'threeprime' for Single Cell 3', 'fiveprime' for  Single Cell 5', 'SC3Pv1' or\n                                  'SC3Pv2' or 'SC3Pv3' for Single Cell 3' v1/v2/v3, 'SC5P-PE' or 'SC5P-R2' for Single Cell 5', paired-end/R2-only, 'SC-FB' for Single Cell Antibody-\n                                  only 3' v2 or 5' [default: auto]\n        --jobmode <MODE>          Job manager to use. Valid options: local (default), sge, lsf, slurm or a .template file. Search for help on \"Cluster Mode\" at\n                                  support.10xgenomics.com for more details on configuring the pipeline to use a compute cluster [default: local]\n        --localcores <NUM>        Set max cores the pipeline may request at one time. Only applies to local jobs\n        --localmem <NUM>          Set max GB the pipeline may request at one time. Only applies to local jobs\n        --localvmem <NUM>         Set max virtual address space in GB for the pipeline. Only applies to local jobs\n        --mempercore <NUM>        Reserve enough threads for each job to ensure enough memory will be available, assuming each core on your cluster has at least this much memory\n                                  available. Only applies in cluster jobmodes\n        --maxjobs <NUM>           Set max jobs submitted to cluster at one time. Only applies in cluster jobmodes\n        --jobinterval <NUM>       Set delay between submitting jobs to cluster, in ms. Only applies in cluster jobmodes\n        --overrides <PATH>        The path to a JSON file that specifies stage-level overrides for cores and memory. Finer-grained than --localcores, --mempercore and --localmem.\n                                  Consult the 10x support website for an example override file\n        --uiport <PORT>           Serve web UI at http://localhost:PORT",
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "sample/outs/filtered_feature_bc_matrix"
                    },
                    "doc": "Folder with filtered feature-barcode matrices containing only cellular barcodes in MEX format.\nWhen implemented, in Targeted Gene Expression samples, the non-targeted genes won't be present.\n",
                    "id": "#cellranger-count.cwl/filtered_feature_bc_matrix_folder"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "sample/outs/filtered_feature_bc_matrix.h5"
                    },
                    "doc": "Filtered feature-barcode matrices containing only cellular barcodes in HDF5 format.\nWhen implemented, in Targeted Gene Expression samples, the non-targeted genes won't\nbe present.\n",
                    "id": "#cellranger-count.cwl/filtered_feature_bc_matrix_h5"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "sample/outs/cloupe.cloupe"
                    },
                    "doc": "Loupe Browser visualization and analysis file\n",
                    "id": "#cellranger-count.cwl/loupe_browser_track"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "sample/outs/metrics_summary.csv"
                    },
                    "doc": "Run summary metrics in CSV format\n",
                    "id": "#cellranger-count.cwl/metrics_summary_report"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "sample/outs/molecule_info.h5"
                    },
                    "doc": "Molecule-level information used by cellranger aggr to aggregate samples into\nlarger datasets\n",
                    "id": "#cellranger-count.cwl/molecule_info_h5"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "sample/outs/possorted_genome_bam.bam"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "doc": "Indexed reads aligned to the genome and transcriptome annotated with barcode information\n",
                    "id": "#cellranger-count.cwl/possorted_genome_bam_bai"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "sample/outs/raw_feature_bc_matrix"
                    },
                    "doc": "Folder with unfiltered feature-barcode matrices containing all barcodes in MEX format\n",
                    "id": "#cellranger-count.cwl/raw_feature_bc_matrices_folder"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "sample/outs/raw_feature_bc_matrix.h5"
                    },
                    "doc": "Unfiltered feature-barcode matrices containing all barcodes in HDF5 format\n",
                    "id": "#cellranger-count.cwl/raw_feature_bc_matrices_h5"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "sample/outs/analysis"
                    },
                    "doc": "Folder with secondary analysis results including dimensionality reduction,\ncell clustering, and differential expression\n",
                    "id": "#cellranger-count.cwl/secondary_analysis_report_folder"
                },
                {
                    "type": "File",
                    "id": "#cellranger-count.cwl/stderr_log",
                    "outputBinding": {
                        "glob": "cellranger_count_stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#cellranger-count.cwl/stdout_log",
                    "outputBinding": {
                        "glob": "cellranger_count_stdout.log"
                    }
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "sample/outs/web_summary.html"
                    },
                    "doc": "Run summary metrics and charts in HTML format\n",
                    "id": "#cellranger-count.cwl/web_summary_report"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.3"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 6
                    },
                    "doc": "Compressed or uncompressed FASTQ file(s)\n",
                    "id": "#extract-fastq.cwl/compressed_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "#!/bin/bash\nshopt -s nocaseglob\nset -- \"$0\" \"$@\"\n\nfunction extract {\n  FILE=$1\n  COMBINED=$2\n  T=`file -b \"${FILE}\" | awk '{print $1}'`\n  case \"${T}\" in\n    \"bzip2\"|\"gzip\"|\"Zip\")\n      7z e -so \"${FILE}\" >> \"${COMBINED}\"\n      ;;\n    \"ASCII\")\n      cat \"${FILE}\" >> \"${COMBINED}\" || true\n      ;;\n    *)\n      echo \"Error: file type unknown\"\n      rm -f \"${COMBINED}\"\n      exit 1\n  esac\n} \n\nCOMBINED=\"\"\nfor FILE in \"$@\"; do\n    BASENAME=$(basename \"$FILE\")\n    ROOTNAME=\"${BASENAME%.*}\"\n    EXT_LIST=( \".fastq\" \".fq\" )\n    for ITEM in $EXT_LIST; do\n      if [[ $ROOTNAME == *$ITEM ]]; then\n        ROOTNAME=\"${ROOTNAME%.*}\"\n      fi\n    done\n    if [[ $COMBINED == \"\" ]]; then\n      COMBINED=\"${ROOTNAME}\"\n    else\n      COMBINED=\"${COMBINED}\"_\"${ROOTNAME}\"\n    fi\ndone\nCOMBINED=\"${COMBINED}\".fastq\n\nfor FILE in \"$@\"; do\n    echo \"Extracting:\" $FILE;\n    extract \"${FILE}\" \"${COMBINED}\"\ndone;\n",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "Bash script to extract compressed FASTQ file\n",
                    "id": "#extract-fastq.cwl/script"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*"
                    },
                    "id": "#extract-fastq.cwl/fastq_file"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "doc": "Tool to decompress input FASTQ file(s).\nIf several FASTQ files are provided, they will be concatenated in the order that corresponds to files in input.\nBash script's logic:\n- disable case sensitive glob check\n- check if root name of input file already include '.fastq' or '.fq' extension. If yes, set DEFAULT_EXT to \"\",\n  otherwise use '.fastq'\n- check file type, decompress if needed\n- return 1, if file type is not recognized\nThis script also works of input file doesn't have any extension at all\n",
            "id": "#extract-fastq.cwl",
            "http://schema.org/name": "extract-fastq",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/extract-fastq.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Tool to decompress input FASTQ file"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/fastqc:v0.11.5"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "prefix": "--adapters"
                    },
                    "doc": "Specifies a non-default file which contains the list of\nadapter sequences which will be explicity searched against\nthe library. The file must contain sets of named adapters\nin the form name[tab]sequence.  Lines prefixed with a hash\nwill be ignored.\n",
                    "id": "#fastqc.cwl/adapters"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "--casava"
                    },
                    "doc": "Files come from raw casava output. Files in the same sample\ngroup (differing only by the group number) will be analysed\nas a set rather than individually. Sequences with the filter\nflag set in the header will be excluded from the analysis.\nFiles must have the same names given to them by casava\n(including being gzipped and ending with .gz) otherwise they\nwon't be grouped together correctly.\n",
                    "id": "#fastqc.cwl/casava"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "--contaminants"
                    },
                    "doc": "Specifies a non-default file which contains the list of\ncontaminants to screen overrepresented sequences against.\nThe file must contain sets of named contaminants in the\nform name[tab]sequence.  Lines prefixed with a hash will\nbe ignored.\n",
                    "id": "#fastqc.cwl/contaminants"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#fastqc.cwl/format_enum/format",
                            "symbols": [
                                "#fastqc.cwl/format_enum/format/bam",
                                "#fastqc.cwl/format_enum/format/sam",
                                "#fastqc.cwl/format_enum/format/bam_mapped",
                                "#fastqc.cwl/format_enum/format/sam_mapped",
                                "#fastqc.cwl/format_enum/format/fastq"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--format"
                    },
                    "doc": "Bypasses the normal sequence file format detection and\nforces the program to use the specified format.  Valid\nformats are bam,sam,bam_mapped,sam_mapped and fastq\n",
                    "id": "#fastqc.cwl/format_enum"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "prefix": "--nogroup"
                    },
                    "doc": "Disable grouping of bases for reads >50bp. All reports will\nshow data for every base in the read.  WARNING: Using this\noption will cause fastqc to crash and burn if you use it on\nreally long reads, and your plots may end up a ridiculous size.\nYou have been warned!\n",
                    "id": "#fastqc.cwl/hide_group"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "--kmers"
                    },
                    "doc": "Specifies the length of Kmer to look for in the Kmer content\nmodule. Specified Kmer length must be between 2 and 10. Default\nlength is 7 if not specified.\n",
                    "id": "#fastqc.cwl/kmers"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "--limits"
                    },
                    "doc": "Specifies a non-default file which contains a set of criteria\nwhich will be used to determine the warn/error limits for the\nvarious modules.  This file can also be used to selectively\nremove some modules from the output all together.  The format\nneeds to mirror the default limits.txt file found in the\nConfiguration folder.\n",
                    "id": "#fastqc.cwl/limits"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "--nofilter"
                    },
                    "doc": "If running with --casava then don't remove read flagged by\ncasava as poor quality when performing the QC analysis.\n",
                    "id": "#fastqc.cwl/nofilter"
                },
                {
                    "type": [
                        "File"
                    ],
                    "inputBinding": {
                        "position": 50
                    },
                    "doc": "Input bam,sam,bam_mapped,sam_mapped or fastq file\n",
                    "id": "#fastqc.cwl/reads_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "--threads"
                    },
                    "doc": "Specifies the number of files which can be processed\nsimultaneously.  Each thread will be allocated 250MB of\nmemory so you shouldn't run more threads than your\navailable memory will cope with, and not more than\n6 threads on a 32 bit machine\n",
                    "id": "#fastqc.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*.html"
                    },
                    "id": "#fastqc.cwl/html_file"
                },
                {
                    "type": [
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  return \"*/summary.txt\";\n}\n"
                    },
                    "id": "#fastqc.cwl/summary_file"
                },
                {
                    "type": [
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*.zip"
                    },
                    "id": "#fastqc.cwl/zipped_file"
                }
            ],
            "baseCommand": [
                "fastqc",
                "--extract",
                "--outdir",
                "."
            ],
            "doc": "Tool runs FastQC from Babraham Bioinformatics\n",
            "id": "#fastqc.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#fastqc-metadata.yaml",
                "http://schema.org/name": "fastqc",
                "http://schema.org/about": "FastQC is a program designed to spot potential problems in high througput sequencing datasets.\nIt runs a set of analyses on one or more raw sequence files in fastq or bam format and produces\na report which summarises the results.\n",
                "http://schema.org/url": "http://www.bioinformatics.babraham.ac.uk/projects/fastqc/",
                "http://schema.org/codeRepository": "https://github.com/s-andrews/FastQC/releases",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/GPL-2.0"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "0.11.5",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "Java",
                "http://schema.org/discussionUrl": [
                    "https://github.com/s-andrews/FastQC/issues"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Babraham Bioinformatics",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Simon Andrews"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/name": "fastqc",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/fastqc.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "SYNOPSIS\n\n    fastqc seqfile1 seqfile2 .. seqfileN\n\n    fastqc [-o output dir] [--(no)extract] [-f fastq|bam|sam]\n           [-c contaminant file] seqfile1 .. seqfileN\n\nDESCRIPTION\n\n    FastQC reads a set of sequence files and produces from each one a quality\n    control report consisting of a number of different modules, each one of\n    which will help to identify a different potential type of problem in your\n    data.\n\n    If no files to process are specified on the command line then the program\n    will start as an interactive graphical application.  If files are provided\n    on the command line then the program will run with no user interaction\n    required.  In this mode it is suitable for inclusion into a standardised\n    analysis pipeline.\n\n    The options for the program as as follows:\n\n    -h --help       Print this help file and exit\n\n    -v --version    Print the version of the program and exit\n\n    -o --outdir     Create all output files in the specified output directory.\n                    Please note that this directory must exist as the program\n                    will not create it.  If this option is not set then the\n                    output file for each sequence file is created in the same\n                    directory as the sequence file which was processed.\n\n    --casava        Files come from raw casava output. Files in the same sample\n                    group (differing only by the group number) will be analysed\n                    as a set rather than individually. Sequences with the filter\n                    flag set in the header will be excluded from the analysis.\n                    Files must have the same names given to them by casava\n                    (including being gzipped and ending with .gz) otherwise they\n                    won't be grouped together correctly.\n\n    --nano          Files come from naopore sequences and are in fast5 format. In\n                    this mode you can pass in directories to process and the program\n                    will take in all fast5 files within those directories and produce\n                    a single output file from the sequences found in all files.\n\n    --nofilter      If running with --casava then don't remove read flagged by\n                    casava as poor quality when performing the QC analysis.\n\n    --extract       If set then the zipped output file will be uncompressed in\n                    the same directory after it has been created.  By default\n                    this option will be set if fastqc is run in non-interactive\n                    mode.\n\n    -j --java       Provides the full path to the java binary you want to use to\n                    launch fastqc. If not supplied then java is assumed to be in\n                    your path.\n\n    --noextract     Do not uncompress the output file after creating it.  You\n                    should set this option if you do not wish to uncompress\n                    the output when running in non-interactive mode.\n\n    --nogroup       Disable grouping of bases for reads >50bp. All reports will\n                    show data for every base in the read.  WARNING: Using this\n                    option will cause fastqc to crash and burn if you use it on\n                    really long reads, and your plots may end up a ridiculous size.\n                    You have been warned!\n\n    -f --format     Bypasses the normal sequence file format detection and\n                    forces the program to use the specified format.  Valid\n                    formats are bam,sam,bam_mapped,sam_mapped and fastq\n\n    -t --threads    Specifies the number of files which can be processed\n                    simultaneously.  Each thread will be allocated 250MB of\n                    memory so you shouldn't run more threads than your\n                    available memory will cope with, and not more than\n                    6 threads on a 32 bit machine\n\n    -c              Specifies a non-default file which contains the list of\n    --contaminants  contaminants to screen overrepresented sequences against.\n                    The file must contain sets of named contaminants in the\n                    form name[tab]sequence.  Lines prefixed with a hash will\n                    be ignored.\n\n    -a              Specifies a non-default file which contains the list of\n    --adapters      adapter sequences which will be explicity searched against\n                    the library. The file must contain sets of named adapters\n                    in the form name[tab]sequence.  Lines prefixed with a hash\n                    will be ignored.\n\n    -l              Specifies a non-default file which contains a set of criteria\n    --limits        which will be used to determine the warn/error limits for the\n                    various modules.  This file can also be used to selectively\n                    remove some modules from the output all together.  The format\n                    needs to mirror the default limits.txt file found in the\n                    Configuration folder.\n\n   -k --kmers       Specifies the length of Kmer to look for in the Kmer content\n                    module. Specified Kmer length must be between 2 and 10. Default\n                    length is 7 if not specified.\n\n   -q --quiet       Supress all progress messages on stdout and only report errors.\n\n   -d --dir         Selects a directory to be used for temporary files written when\n                    generating report images. Defaults to system temp directory if\n                    not specified.\n"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "doc": "Expression threshold for displaying target genes on a plot (expression > threshold)",
                    "id": "#soupx-subworkflow.cwl/expression_threshold"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "doc": "FDR cutoff for expression ratio plots",
                    "id": "#soupx-subworkflow.cwl/fdr"
                },
                {
                    "type": "File",
                    "doc": "Compressed folder with filtered feature-barcode matrices",
                    "id": "#soupx-subworkflow.cwl/filtered_feature_bc_matrix_folder"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "Target genes list. Headerless text file with 1 gene per line",
                    "id": "#soupx-subworkflow.cwl/genelist_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#soupx-subworkflow.cwl/matrix_format_version/matrix_format_version",
                            "symbols": [
                                "#soupx-subworkflow.cwl/matrix_format_version/matrix_format_version/2",
                                "#soupx-subworkflow.cwl/matrix_format_version/matrix_format_version/3"
                            ]
                        }
                    ],
                    "doc": "Output matrix format version. Corresponds to the latest Cell Ranger matrix format",
                    "id": "#soupx-subworkflow.cwl/matrix_format_version"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Output prefix",
                    "id": "#soupx-subworkflow.cwl/output_prefix"
                },
                {
                    "type": "File",
                    "doc": "Compressed folder with unfiltered feature-barcode matrices",
                    "id": "#soupx-subworkflow.cwl/raw_feature_bc_matrices_folder"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Round adjusted counts to integers",
                    "id": "#soupx-subworkflow.cwl/round_counts"
                },
                {
                    "type": "File",
                    "doc": "Compressed folder with secondary analysis results",
                    "id": "#soupx-subworkflow.cwl/secondary_analysis_report_folder"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#soupx-subworkflow.cwl/compress_adjusted_feature_bc_matrices_folder/compressed_folder",
                    "doc": "Compressed folder with adjusted feature-barcode matrices in MEX format",
                    "id": "#soupx-subworkflow.cwl/adjusted_feature_bc_matrices_folder"
                },
                {
                    "type": "File",
                    "outputSource": "#soupx-subworkflow.cwl/estimate_contamination/adjusted_feature_bc_matrices_h5",
                    "doc": "Adjusted feature-barcode matrices in HDF5 format",
                    "id": "#soupx-subworkflow.cwl/adjusted_feature_bc_matrices_h5"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#soupx-subworkflow.cwl/estimate_contamination/adjusted_gene_expression_plots",
                    "doc": "Adjusted gene expression plots",
                    "id": "#soupx-subworkflow.cwl/adjusted_gene_expression_plots"
                },
                {
                    "type": "File",
                    "outputSource": "#soupx-subworkflow.cwl/estimate_contamination/contamination_estimation_plot",
                    "doc": "Contamination estimation plot",
                    "id": "#soupx-subworkflow.cwl/contamination_estimation_plot"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#soupx-subworkflow.cwl/estimate_contamination/raw_gene_expression_plots",
                    "doc": "Raw gene expression plots",
                    "id": "#soupx-subworkflow.cwl/raw_gene_expression_plots"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#soupx-subworkflow.cwl/estimate_contamination/raw_gene_expression_to_pure_soup_ratio_plots",
                    "doc": "Raw gene expression to pure soup ratio plots",
                    "id": "#soupx-subworkflow.cwl/raw_gene_expression_to_pure_soup_ratio_plots"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#soupx-subworkflow.cwl/estimate_contamination/raw_to_adjusted_gene_expression_ratio_plots",
                    "doc": "Raw to adjusted gene expression ratio plots",
                    "id": "#soupx-subworkflow.cwl/raw_to_adjusted_gene_expression_ratio_plots"
                },
                {
                    "type": "File",
                    "outputSource": "#soupx-subworkflow.cwl/estimate_contamination/stderr_log",
                    "doc": "SoupX stderr log",
                    "id": "#soupx-subworkflow.cwl/soupx_stderr_log"
                },
                {
                    "type": "File",
                    "outputSource": "#soupx-subworkflow.cwl/estimate_contamination/stdout_log",
                    "doc": "SoupX stdout log",
                    "id": "#soupx-subworkflow.cwl/soupx_stdout_log"
                }
            ],
            "steps": [
                {
                    "run": "#tar-compress.cwl",
                    "in": [
                        {
                            "source": "#soupx-subworkflow.cwl/estimate_contamination/adjusted_feature_bc_matrices_folder",
                            "id": "#soupx-subworkflow.cwl/compress_adjusted_feature_bc_matrices_folder/folder_to_compress"
                        }
                    ],
                    "out": [
                        "#soupx-subworkflow.cwl/compress_adjusted_feature_bc_matrices_folder/compressed_folder"
                    ],
                    "id": "#soupx-subworkflow.cwl/compress_adjusted_feature_bc_matrices_folder"
                },
                {
                    "run": "#soupx.cwl",
                    "in": [
                        {
                            "source": "#soupx-subworkflow.cwl/expression_threshold",
                            "id": "#soupx-subworkflow.cwl/estimate_contamination/expression_threshold"
                        },
                        {
                            "source": "#soupx-subworkflow.cwl/fdr",
                            "id": "#soupx-subworkflow.cwl/estimate_contamination/fdr"
                        },
                        {
                            "source": "#soupx-subworkflow.cwl/extract_count_matrices_to_folder/output_folder",
                            "id": "#soupx-subworkflow.cwl/estimate_contamination/feature_bc_matrices_folder"
                        },
                        {
                            "source": "#soupx-subworkflow.cwl/genelist_file",
                            "id": "#soupx-subworkflow.cwl/estimate_contamination/genelist_file"
                        },
                        {
                            "source": "#soupx-subworkflow.cwl/matrix_format_version",
                            "id": "#soupx-subworkflow.cwl/estimate_contamination/matrix_format_version"
                        },
                        {
                            "source": "#soupx-subworkflow.cwl/output_prefix",
                            "id": "#soupx-subworkflow.cwl/estimate_contamination/output_prefix"
                        },
                        {
                            "source": "#soupx-subworkflow.cwl/round_counts",
                            "id": "#soupx-subworkflow.cwl/estimate_contamination/round_counts"
                        }
                    ],
                    "out": [
                        "#soupx-subworkflow.cwl/estimate_contamination/adjusted_feature_bc_matrices_folder",
                        "#soupx-subworkflow.cwl/estimate_contamination/adjusted_feature_bc_matrices_h5",
                        "#soupx-subworkflow.cwl/estimate_contamination/contamination_estimation_plot",
                        "#soupx-subworkflow.cwl/estimate_contamination/raw_gene_expression_plots",
                        "#soupx-subworkflow.cwl/estimate_contamination/adjusted_gene_expression_plots",
                        "#soupx-subworkflow.cwl/estimate_contamination/raw_gene_expression_to_pure_soup_ratio_plots",
                        "#soupx-subworkflow.cwl/estimate_contamination/raw_to_adjusted_gene_expression_ratio_plots",
                        "#soupx-subworkflow.cwl/estimate_contamination/stdout_log",
                        "#soupx-subworkflow.cwl/estimate_contamination/stderr_log"
                    ],
                    "id": "#soupx-subworkflow.cwl/estimate_contamination"
                },
                {
                    "run": {
                        "cwlVersion": "v1.0",
                        "class": "CommandLineTool",
                        "hints": [
                            {
                                "class": "DockerRequirement",
                                "dockerPull": "scidap/scidap:v0.0.4"
                            }
                        ],
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "inputBinding": {
                                    "position": 2
                                },
                                "id": "#soupx-subworkflow.cwl/extract_count_matrices_to_folder/c0ae9736-d0f4-4612-a3ed-08ff342fb611/compressed_files"
                            },
                            {
                                "type": [
                                    "null",
                                    "string"
                                ],
                                "default": "set -- \"$0\" \"$@\"\nmkdir counts && cd counts\nfor i in \"$@\";\n    do tar xvf $i;\ndone;\n",
                                "inputBinding": {
                                    "position": 1
                                },
                                "id": "#soupx-subworkflow.cwl/extract_count_matrices_to_folder/c0ae9736-d0f4-4612-a3ed-08ff342fb611/script"
                            }
                        ],
                        "outputs": [
                            {
                                "type": "Directory",
                                "outputBinding": {
                                    "glob": "counts"
                                },
                                "id": "#soupx-subworkflow.cwl/extract_count_matrices_to_folder/c0ae9736-d0f4-4612-a3ed-08ff342fb611/output_folder"
                            }
                        ],
                        "baseCommand": [
                            "bash",
                            "-c"
                        ],
                        "id": "#soupx-subworkflow.cwl/extract_count_matrices_to_folder/c0ae9736-d0f4-4612-a3ed-08ff342fb611"
                    },
                    "in": [
                        {
                            "source": [
                                "#soupx-subworkflow.cwl/raw_feature_bc_matrices_folder",
                                "#soupx-subworkflow.cwl/filtered_feature_bc_matrix_folder",
                                "#soupx-subworkflow.cwl/secondary_analysis_report_folder"
                            ],
                            "id": "#soupx-subworkflow.cwl/extract_count_matrices_to_folder/compressed_files"
                        }
                    ],
                    "out": [
                        "#soupx-subworkflow.cwl/extract_count_matrices_to_folder/output_folder"
                    ],
                    "id": "#soupx-subworkflow.cwl/extract_count_matrices_to_folder"
                }
            ],
            "label": "SoupX (workflow) - an R package for the estimation and removal of cell free mRNA contamination",
            "doc": "Wrapped in a workflow SoupX tool for easy access to Cell Ranger pipeline compressed outputs.\n",
            "id": "#soupx-subworkflow.cwl",
            "http://schema.org/name": "SoupX (workflow) - an R package for the estimation and removal of cell free mRNA contamination",
            "http://schema.org/alternateName": "SoupX (workflow) - an R package for the estimation and removal of cell free mRNA contamination",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/soupx-subworkflow.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Wrapped in a workflow SoupX tool for easy access to Cell Ranger pipeline compressed outputs."
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/soupx:v0.0.1"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--threshold"
                    },
                    "doc": "Expression threshold for displaying target genes on a plot (expression > threshold)\nDefault: 0.0\n",
                    "id": "#soupx.cwl/expression_threshold"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--fdr"
                    },
                    "doc": "FDR cutoff for expression ratio plots\nDefault: 0.05\n",
                    "id": "#soupx.cwl/fdr"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "--counts"
                    },
                    "doc": "Path to the output folder produced by 'cellranger count' command\n",
                    "id": "#soupx.cwl/feature_bc_matrices_folder"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--genes"
                    },
                    "doc": "Path to the file with target genes (headerless, one gene per line)\n",
                    "id": "#soupx.cwl/genelist_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#soupx.cwl/matrix_format_version/matrix_format_version",
                            "symbols": [
                                "#soupx.cwl/matrix_format_version/matrix_format_version/2",
                                "#soupx.cwl/matrix_format_version/matrix_format_version/3"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--format"
                    },
                    "doc": "Output matrix format version. Corresponds to the latest Cell Ranger matrix format\nDefault: 3\n",
                    "id": "#soupx.cwl/matrix_format_version"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--output"
                    },
                    "doc": "Output prefix\nDefault: soupx\n",
                    "id": "#soupx.cwl/output_prefix"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--round"
                    },
                    "doc": "Round adjusted counts to integers\nDefault: False\n",
                    "id": "#soupx.cwl/round_counts"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "*adjusted_counts"
                    },
                    "doc": "Folder with adjusted feature-barcode matrices in MEX format\n",
                    "id": "#soupx.cwl/adjusted_feature_bc_matrices_folder"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*adjusted_counts.h5"
                    },
                    "doc": "Adjusted feature-barcode matrices in HDF5 format\n",
                    "id": "#soupx.cwl/adjusted_feature_bc_matrices_h5"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*adjusted_gene_expression_plots.pdf"
                    },
                    "doc": "Adjusted gene expression plots\n",
                    "id": "#soupx.cwl/adjusted_gene_expression_plots"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*contamination_estimation_plot.pdf"
                    },
                    "doc": "Contamination estimation plot\n",
                    "id": "#soupx.cwl/contamination_estimation_plot"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*raw_gene_expression_plots.pdf"
                    },
                    "doc": "Raw gene expression plots\n",
                    "id": "#soupx.cwl/raw_gene_expression_plots"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*raw_gene_expression_to_pure_soup_ratio_plots.pdf"
                    },
                    "doc": "Raw gene expression to pure soup ratio plots\n",
                    "id": "#soupx.cwl/raw_gene_expression_to_pure_soup_ratio_plots"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*raw_to_adjusted_gene_expression_ratio_plots.pdf"
                    },
                    "doc": "Raw to adjusted gene expression ratio plots\n",
                    "id": "#soupx.cwl/raw_to_adjusted_gene_expression_ratio_plots"
                },
                {
                    "type": "File",
                    "id": "#soupx.cwl/stderr_log",
                    "outputBinding": {
                        "glob": "soupx_stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#soupx.cwl/stdout_log",
                    "outputBinding": {
                        "glob": "soupx_stdout.log"
                    }
                }
            ],
            "baseCommand": [
                "run_soupx.R"
            ],
            "stdout": "soupx_stdout.log",
            "stderr": "soupx_stderr.log",
            "label": "SoupX - an R package for the estimation and removal of cell free mRNA contamination",
            "doc": "In droplet based, single cell RNA-seq experiments, there is always a certain amount of background\nmRNAs present in the dilution that gets distributed into the droplets with cells and sequenced\nalong with them. The net effect of this is to produce a background contamination that represents\nexpression not from the cell contained within a droplet, but the solution that contained the cells.\n\nThis collection of cell free mRNAs floating in the input solution (henceforth referred to as\n\u201cthe soup\u201d) is created from cells in the input solution being lysed. Because of this, the soup looks\ndifferent for each input solution and strongly resembles the expression pattern obtained by summing\nall the individual cells.\n\nThe aim of this package is to provide a way to estimate the composition of this soup, what fraction\nof UMIs are derived from the soup in each droplet and produce a corrected count table with the soup\nbased expression removed.\n\nThe method to do this consists of three parts:\n\n- Calculate the profile of the soup.\n- Estimate the cell specific contamination fraction.\n- Infer a corrected expression matrix.  \n",
            "id": "#soupx.cwl",
            "http://schema.org/name": "SoupX - an R package for the estimation and removal of cell free mRNA contamination",
            "http://schema.org/alternateName": "SoupX - an R package for the estimation and removal of cell free mRNA contamination",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/soupx.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "usage: run_soupx.R [-h] --counts COUNTS [--genes GENES]\n                                  [--threshold THRESHOLD] [--fdr FDR]\n                                  [--round] [--format {2,3}] [--output OUTPUT]\n\nRuns SoupX - an R package for the estimation and removal of cell free mRNA\ncontamination\n\noptional arguments:\n  -h, --help            show this help message and exit\n  --counts COUNTS       Path to the output folder produced by 'cellranger\n                        count' command\n  --genes GENES         Path to the file with target genes (headerless, one\n                        gene per line)\n  --threshold THRESHOLD\n                        Expression threshold for displaying target genes on a\n                        plot (expression > threshold). Default: 0.0\n  --fdr FDR             FDR cutoff for expression ratio plots. Default: 0.05\n  --round               Round adjusted counts to integers\n  --format {2,3}        Output matrix format version. Default: 3 (corresponds\n                        to the latest Cell Ranger matrix format)\n  --output OUTPUT       Output prefix. Default: soupx"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.3"
                }
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "doc": "Folder to compressed",
                    "id": "#tar-compress.cwl/folder_to_compress"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*"
                    },
                    "doc": "Compressed folder",
                    "id": "#tar-compress.cwl/compressed_folder"
                }
            ],
            "baseCommand": [
                "tar"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.folder_to_compress.path.split(\"/\").slice(0,-1).join(\"/\"))",
                    "prefix": "-C"
                },
                "-czvf",
                {
                    "valueFrom": "$(inputs.folder_to_compress.basename + \".tar.gz\")"
                },
                "."
            ],
            "doc": "Compresses input directory to tar.gz\n",
            "id": "#tar-compress.cwl",
            "http://schema.org/name": "tar-compress",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/tar-compress.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "sd:upstream": {
                "genome_indices": [
                    "cellranger-mkref.cwl"
                ]
            },
            "inputs": [
                {
                    "type": "string",
                    "label": "Experiment short name/Alias",
                    "sd:preview": {
                        "position": 1
                    },
                    "id": "#main/alias"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "label": "FASTQ file R1 (optionally compressed)",
                    "doc": "FASTQ file R1 (optionally compressed)",
                    "id": "#main/fastq_file_r1"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "label": "FASTQ file R2 (optionally compressed)",
                    "doc": "FASTQ file R2 (optionally compressed)",
                    "id": "#main/fastq_file_r2"
                },
                {
                    "type": "Directory",
                    "label": "Genome Type",
                    "doc": "Cell Ranger generated genome indices folder",
                    "sd:upstreamSource": "genome_indices/indices_folder",
                    "sd:localLabel": true,
                    "id": "#main/indices_folder"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 30,
                    "label": "Genome Type",
                    "doc": "Maximum memory used (GB).\nThe same as was used for generating indices.\nThe same will be applied to virtual memory\n",
                    "sd:upstreamSource": "genome_indices/memory_limit",
                    "sd:localLabel": true,
                    "id": "#main/memory_limit"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 4,
                    "label": "Number of threads",
                    "doc": "Number of threads for those steps that support multithreading",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/estimate_contamination/adjusted_feature_bc_matrices_folder",
                    "label": "Compressed folder with SoupX adjusted feature-barcode matrices",
                    "doc": "Compressed folder with SoupX adjusted feature-barcode matrices in MEX format\n",
                    "id": "#main/adjusted_feature_bc_matrices_folder"
                },
                {
                    "type": "File",
                    "outputSource": "#main/estimate_contamination/adjusted_feature_bc_matrices_h5",
                    "label": "SoupX adjusted feature-barcode matrices in HDF5 format",
                    "doc": "SoupX adjusted feature-barcode matrices in HDF5 format\n",
                    "id": "#main/adjusted_feature_bc_matrices_h5"
                },
                {
                    "type": "File",
                    "outputSource": "#main/collect_statistics/collected_statistics",
                    "label": "Collected statistics in Markdown format",
                    "doc": "Collected statistics in Markdown format",
                    "sd:visualPlugins": [
                        {
                            "markdownView": {
                                "tab": "Overview"
                            }
                        }
                    ],
                    "id": "#main/collected_statistics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/estimate_contamination/contamination_estimation_plot",
                    "label": "SoupX contamination estimation plot",
                    "doc": "SoupX contamination estimation plot\n",
                    "id": "#main/contamination_estimation_plot"
                },
                {
                    "type": "File",
                    "outputSource": "#main/run_fastqc_for_fastq_r1/html_file",
                    "label": "FastqQC report for FASTQ file R1",
                    "doc": "FastqQC report for FASTQ file R1\n",
                    "id": "#main/fastqc_report_fastq_r1"
                },
                {
                    "type": "File",
                    "outputSource": "#main/run_fastqc_for_fastq_r2/html_file",
                    "label": "FastqQC report for FASTQ file R2",
                    "doc": "FastqQC report for FASTQ file R2\n",
                    "id": "#main/fastqc_report_fastq_r2"
                },
                {
                    "type": "File",
                    "outputSource": "#main/compress_filtered_feature_bc_matrix_folder/compressed_folder",
                    "label": "Compressed folder with filtered feature-barcode matrices",
                    "doc": "Compressed folder with filtered feature-barcode matrices containing only cellular barcodes in MEX format.\nWhen implemented, in Targeted Gene Expression samples, the non-targeted genes won't be present.\n",
                    "id": "#main/filtered_feature_bc_matrix_folder"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_counts_matrix/filtered_feature_bc_matrix_h5",
                    "label": "Filtered feature-barcode matrices in HDF5 format",
                    "doc": "Filtered feature-barcode matrices containing only cellular barcodes in HDF5 format.\nWhen implemented, in Targeted Gene Expression samples, the non-targeted genes won't\nbe present.\n",
                    "id": "#main/filtered_feature_bc_matrix_h5"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_counts_matrix/stderr_log",
                    "label": "stderr log generated by cellranger count",
                    "doc": "stderr log generated by cellranger count\n",
                    "id": "#main/generate_counts_matrix_stderr_log"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_counts_matrix/stdout_log",
                    "label": "stdout log generated by cellranger count",
                    "doc": "stdout log generated by cellranger count\n",
                    "id": "#main/generate_counts_matrix_stdout_log"
                },
                {
                    "outputSource": "#main/generate_counts_matrix/loupe_browser_track",
                    "label": "Loupe Browser visualization and analysis file",
                    "type": "File",
                    "doc": "Loupe Browser visualization and analysis file\n",
                    "id": "#main/loupe_browser_track"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_counts_matrix/metrics_summary_report",
                    "label": "Run summary metrics in CSV format",
                    "doc": "Run summary metrics in CSV format\n",
                    "id": "#main/metrics_summary_report"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_counts_matrix/molecule_info_h5",
                    "label": "Molecule-level information for aggregating samples into larger datasets",
                    "doc": "Molecule-level information used by cellranger aggr to aggregate samples into\nlarger datasets\n",
                    "id": "#main/molecule_info_h5"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_counts_matrix/possorted_genome_bam_bai",
                    "label": "Aligned to the genome indexed reads BAM+BAI files",
                    "doc": "Indexed reads aligned to the genome and transcriptome annotated\nwith barcode information\n",
                    "sd:visualPlugins": [
                        {
                            "igvbrowser": {
                                "tab": "IGV Genome Browser",
                                "id": "#main/possorted_genome_bam_bai/igvbrowser",
                                "optional": true,
                                "type": "alignment",
                                "format": "#main/possorted_genome_bam_bai/bam",
                                "name": "#main/possorted_genome_bam_bai/BAM Track",
                                "displayMode": "SQUISHED"
                            }
                        }
                    ],
                    "id": "#main/possorted_genome_bam_bai"
                },
                {
                    "type": "File",
                    "outputSource": "#main/compress_raw_feature_bc_matrices_folder/compressed_folder",
                    "label": "Compressed folder with unfiltered feature-barcode matrices",
                    "doc": "Compressed folder with unfiltered feature-barcode matrices containing all barcodes in MEX format\n",
                    "id": "#main/raw_feature_bc_matrices_folder"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_counts_matrix/raw_feature_bc_matrices_h5",
                    "label": "Unfiltered feature-barcode matrices in HDF5 format",
                    "doc": "Unfiltered feature-barcode matrices containing all barcodes in HDF5 format\n",
                    "id": "#main/raw_feature_bc_matrices_h5"
                },
                {
                    "type": "File",
                    "outputSource": "#main/compress_secondary_analysis_report_folder/compressed_folder",
                    "label": "Compressed folder with secondary analysis results",
                    "doc": "Compressed folder with secondary analysis results including dimensionality reduction,\ncell clustering, and differential expression\n",
                    "id": "#main/secondary_analysis_report_folder"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_counts_matrix/web_summary_report",
                    "label": "Run summary metrics and charts in HTML format",
                    "doc": "Run summary metrics and charts in HTML format\n",
                    "id": "#main/web_summary_report"
                }
            ],
            "steps": [
                {
                    "run": {
                        "cwlVersion": "v1.0",
                        "class": "CommandLineTool",
                        "hints": [
                            {
                                "class": "DockerRequirement",
                                "dockerPull": "rackspacedot/python37"
                            }
                        ],
                        "inputs": [
                            {
                                "type": "File",
                                "inputBinding": {
                                    "position": 6
                                },
                                "id": "#main/collect_statistics/c30f89ac-b8c1-4e07-b421-96825c1de92a/metrics_summary_report"
                            },
                            {
                                "type": [
                                    "null",
                                    "string"
                                ],
                                "default": "#!/usr/bin/env python3\nimport sys, csv\nwith open(sys.argv[1], \"r\") as input_stream:\n  with open(\"collected_statistics.md\", \"w\") as output_stream:\n    output_stream.write(\"### Cell Ranger Statistics\\n\")\n    keys, values = None, None\n    for i, row in enumerate(csv.reader(input_stream)):\n      if i==0:\n        keys = row\n      else:\n        values = row\n    for k,v in zip(keys, values):\n      output_stream.write(\"- \"+k+\": \"+v+\"\\n\")\n",
                                "inputBinding": {
                                    "position": 5
                                },
                                "id": "#main/collect_statistics/c30f89ac-b8c1-4e07-b421-96825c1de92a/script"
                            }
                        ],
                        "outputs": [
                            {
                                "type": "File",
                                "outputBinding": {
                                    "glob": "*"
                                },
                                "id": "#main/collect_statistics/c30f89ac-b8c1-4e07-b421-96825c1de92a/collected_statistics"
                            }
                        ],
                        "baseCommand": [
                            "python3",
                            "-c"
                        ],
                        "id": "#main/collect_statistics/c30f89ac-b8c1-4e07-b421-96825c1de92a"
                    },
                    "in": [
                        {
                            "source": "#main/generate_counts_matrix/metrics_summary_report",
                            "id": "#main/collect_statistics/metrics_summary_report"
                        }
                    ],
                    "out": [
                        "#main/collect_statistics/collected_statistics"
                    ],
                    "id": "#main/collect_statistics"
                },
                {
                    "run": "#tar-compress.cwl",
                    "in": [
                        {
                            "source": "#main/generate_counts_matrix/filtered_feature_bc_matrix_folder",
                            "id": "#main/compress_filtered_feature_bc_matrix_folder/folder_to_compress"
                        }
                    ],
                    "out": [
                        "#main/compress_filtered_feature_bc_matrix_folder/compressed_folder"
                    ],
                    "id": "#main/compress_filtered_feature_bc_matrix_folder"
                },
                {
                    "run": "#tar-compress.cwl",
                    "in": [
                        {
                            "source": "#main/generate_counts_matrix/raw_feature_bc_matrices_folder",
                            "id": "#main/compress_raw_feature_bc_matrices_folder/folder_to_compress"
                        }
                    ],
                    "out": [
                        "#main/compress_raw_feature_bc_matrices_folder/compressed_folder"
                    ],
                    "id": "#main/compress_raw_feature_bc_matrices_folder"
                },
                {
                    "run": "#tar-compress.cwl",
                    "in": [
                        {
                            "source": "#main/generate_counts_matrix/secondary_analysis_report_folder",
                            "id": "#main/compress_secondary_analysis_report_folder/folder_to_compress"
                        }
                    ],
                    "out": [
                        "#main/compress_secondary_analysis_report_folder/compressed_folder"
                    ],
                    "id": "#main/compress_secondary_analysis_report_folder"
                },
                {
                    "run": "#soupx-subworkflow.cwl",
                    "in": [
                        {
                            "source": "#main/compress_filtered_feature_bc_matrix_folder/compressed_folder",
                            "id": "#main/estimate_contamination/filtered_feature_bc_matrix_folder"
                        },
                        {
                            "source": "#main/compress_raw_feature_bc_matrices_folder/compressed_folder",
                            "id": "#main/estimate_contamination/raw_feature_bc_matrices_folder"
                        },
                        {
                            "source": "#main/compress_secondary_analysis_report_folder/compressed_folder",
                            "id": "#main/estimate_contamination/secondary_analysis_report_folder"
                        }
                    ],
                    "out": [
                        "#main/estimate_contamination/adjusted_feature_bc_matrices_folder",
                        "#main/estimate_contamination/adjusted_feature_bc_matrices_h5",
                        "#main/estimate_contamination/contamination_estimation_plot"
                    ],
                    "id": "#main/estimate_contamination"
                },
                {
                    "run": "#extract-fastq.cwl",
                    "in": [
                        {
                            "source": "#main/fastq_file_r1",
                            "id": "#main/extract_fastq_r1/compressed_file"
                        }
                    ],
                    "out": [
                        "#main/extract_fastq_r1/fastq_file"
                    ],
                    "id": "#main/extract_fastq_r1"
                },
                {
                    "run": "#extract-fastq.cwl",
                    "in": [
                        {
                            "source": "#main/fastq_file_r2",
                            "id": "#main/extract_fastq_r2/compressed_file"
                        }
                    ],
                    "out": [
                        "#main/extract_fastq_r2/fastq_file"
                    ],
                    "id": "#main/extract_fastq_r2"
                },
                {
                    "run": "#cellranger-count.cwl",
                    "in": [
                        {
                            "source": "#main/extract_fastq_r1/fastq_file",
                            "id": "#main/generate_counts_matrix/fastq_file_r1"
                        },
                        {
                            "source": "#main/extract_fastq_r2/fastq_file",
                            "id": "#main/generate_counts_matrix/fastq_file_r2"
                        },
                        {
                            "source": "#main/indices_folder",
                            "id": "#main/generate_counts_matrix/indices_folder"
                        },
                        {
                            "source": "#main/memory_limit",
                            "id": "#main/generate_counts_matrix/memory_limit"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/generate_counts_matrix/threads"
                        },
                        {
                            "source": "#main/memory_limit",
                            "id": "#main/generate_counts_matrix/virt_memory_limit"
                        }
                    ],
                    "out": [
                        "#main/generate_counts_matrix/web_summary_report",
                        "#main/generate_counts_matrix/metrics_summary_report",
                        "#main/generate_counts_matrix/possorted_genome_bam_bai",
                        "#main/generate_counts_matrix/filtered_feature_bc_matrix_folder",
                        "#main/generate_counts_matrix/filtered_feature_bc_matrix_h5",
                        "#main/generate_counts_matrix/raw_feature_bc_matrices_folder",
                        "#main/generate_counts_matrix/raw_feature_bc_matrices_h5",
                        "#main/generate_counts_matrix/secondary_analysis_report_folder",
                        "#main/generate_counts_matrix/molecule_info_h5",
                        "#main/generate_counts_matrix/loupe_browser_track",
                        "#main/generate_counts_matrix/stdout_log",
                        "#main/generate_counts_matrix/stderr_log"
                    ],
                    "id": "#main/generate_counts_matrix"
                },
                {
                    "run": "#fastqc.cwl",
                    "in": [
                        {
                            "source": "#main/extract_fastq_r1/fastq_file",
                            "id": "#main/run_fastqc_for_fastq_r1/reads_file"
                        }
                    ],
                    "out": [
                        "#main/run_fastqc_for_fastq_r1/html_file"
                    ],
                    "id": "#main/run_fastqc_for_fastq_r1"
                },
                {
                    "run": "#fastqc.cwl",
                    "in": [
                        {
                            "source": "#main/extract_fastq_r2/fastq_file",
                            "id": "#main/run_fastqc_for_fastq_r2/reads_file"
                        }
                    ],
                    "out": [
                        "#main/run_fastqc_for_fastq_r2/html_file"
                    ],
                    "id": "#main/run_fastqc_for_fastq_r2"
                }
            ],
            "label": "Single-Cell Preprocessing Cell Ranger Pipeline",
            "doc": "Devel version of Single-Cell Preprocessing Cell Ranger Pipeline\n===============================================================",
            "id": "#main",
            "http://schema.org/name": "Single-Cell Preprocessing Cell Ranger Pipeline",
            "http://schema.org/alternateName": "Single-Cell Preprocessing Cell Ranger Pipeline",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/datirium/workflows/master/workflows/single-cell-preprocess-cellranger.cwl",
            "http://schema.org/codeRepository": "https://github.com/datirium/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://github.com/schemaorg/schemaorg/raw/main/data/releases/11.01/schemaorg-current-http.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
